@@ -17,12 +17,12 @@ rsos_article <- function(
 
   template <- find_resource('rsos')
   args <- c(
-    "--template", template, pandoc_variable_arg("documentclass", "article"),
-    pandoc_args, "--natbib", includes_to_pandoc_args(includes)
+    "--template", template, rmarkdown::pandoc_variable_arg("documentclass", "article"),
+    pandoc_args, "--natbib", rmarkdown::includes_to_pandoc_args(includes)
   )
 
   if (length(extra) > 0) args <- c(args, sapply(names(extra), function(x){
-    pandoc_variable_arg(x, extra[[x]])
+    rmarkdown::pandoc_variable_arg(x, extra[[x]])
   }))
 
   opts_chunk <- list(
